@@ -146,7 +146,7 @@ extern const struct headerSprintfExtension rpmHeaderFormats[];
 #define	RPMTAG_TRIGGERPOSTUN		1102 /* internal */
 #define	RPMTAG_AUTOREQ			1103 /* internal */
 #define	RPMTAG_AUTOPROV			1104 /* internal */
-#define	RPMTAG_CAPABILITY		1105 /* unused */
+#define	RPMTAG_CAPABILITY		1105 /* unused internal */
 #define	RPMTAG_SOURCEPACKAGE		1106 /* internal */
 #define	RPMTAG_OLDORIGFILENAMES		1107 /* obsolete */
 #define	RPMTAG_BUILDPREREQ		1108 /* internal */
@@ -163,8 +163,13 @@ extern const struct headerSprintfExtension rpmHeaderFormats[];
 #define	RPMTAG_ORIGDIRINDEXES		1119 /* internal */
 #define	RPMTAG_ORIGBASENAMES		1120 /* internal */
 #define	RPMTAG_ORIGDIRNAMES		1121 /* internal */
+#define	RPMTAG_OPTFLAGS			1122
+#define	RPMTAG_DISTURL			1123
+#define	RPMTAG_PAYLOADFORMAT		1124
+#define	RPMTAG_PAYLOADCOMPRESSOR	1125
+#define	RPMTAG_PAYLOADFLAGS		1126
 
-#define	RPMTAG_FIRSTFREE_TAG		1122 /* internal */
+#define	RPMTAG_FIRSTFREE_TAG		1127 /* internal */
 #define	RPMTAG_EXTERNAL_TAG		1000000
 
 #define	RPMFILE_STATE_NORMAL 		0
@@ -428,6 +433,20 @@ void rpmdepFreeConflicts( /*@only@*/ struct rpmDependencyConflict * conflicts,
 #define	RPMTRANS_FLAG_ALLFILES		(1 << 6)
 #define	RPMTRANS_FLAG_KEEPOBSOLETE	(1 << 7)
 
+/**
+ */
+int rpmRangesOverlap(const char *AName, const char *AEVR, int AFlags,
+	const char *BName, const char *BEVR, int BFlags);
+
+/**
+ */
+int rpmCheckRpmlibProvides(const char * keyName, const char * keyEVR,
+	int keyFlags);
+
+/**
+ */
+void rpmShowRpmlibProvides(FILE * fp);
+
 typedef enum rpmProblemType_e { RPMPROB_BADARCH, 
 				RPMPROB_BADOS,
 				RPMPROB_PKG_INSTALLED,
@@ -730,6 +749,7 @@ int rpmVerify(QVA_t *qva, enum rpmQVSources source, const char *arg);
 #define INSTALL_NOORDER		(1 << 3)
 #define INSTALL_LABEL		(1 << 4)  /* set if we're being verbose */
 #define INSTALL_UPGRADE		(1 << 5)
+#define INSTALL_FRESHEN		(1 << 6)
 
 #define UNINSTALL_NODEPS	(1 << 0)
 #define UNINSTALL_ALLMATCHES	(1 << 1)
