@@ -22,9 +22,9 @@
 #include "config.h"
 #endif
 
-#include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <stdio.h>
 
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
@@ -89,6 +89,14 @@ extern time_t timezone;
 char *memchr ();
 #endif
 
+#if !defined(HAVE_STPCPY) || defined(__LCLINT__)
+char * stpcpy(char * dest, const char * src);
+#endif
+
+#if !defined(HAVE_STPNCPY) || defined(__LCLINT__)
+char * stpncpy(char * dest, const char * src, size_t n);
+#endif
+
 #include <errno.h>
 #ifndef errno
 extern int errno;
@@ -259,16 +267,17 @@ char *__progname;
 
 /* ============== from misc/miscfn.h */
 
+#if !defined(USE_GNU_GLOB)
 #if HAVE_FNMATCH_H
 #include <fnmatch.h>
-#else
-#include "misc/fnmatch.h"
 #endif
 
 #if HAVE_GLOB_H
 #include <glob.h>
+#endif
 #else
 #include "misc/glob.h"
+#include "misc/fnmatch.h"
 #endif
 
 #if ! HAVE_S_IFSOCK
@@ -296,6 +305,11 @@ char *realpath(const char *path, char resolved_path []);
 extern void *myrealloc(void *, size_t);
 #endif
 
+#if ! HAVE_SETENV
+extern int setenv(const char *name, const char *value, int replace);
+extern void unsetenv(const char *name);
+#endif
+
 #if HAVE_SYS_SOCKET_H
 #include <sys/types.h>
 #ifndef	__LCLINT__
